program read_cps
  !
  ! READ_CPS   reads file avghrs.dat and writes out hours and populations
  !            the year desired (iyear) and characteristics desired.  
  !            The file cps.dat has 2,451,246 records (rows).  The list 
  !            of variables and their lengths is given in cps.sas.

  ! Ellen McGrattan, 8-30-05
 
  implicit none
  integer                :: year,perwt,blswt,age,sex,marst,popstat,educrec,  &
                            empstat,labforce,occ,ind,classwkr,occly,indly,   &
                            classswly,hrswork,uhrswork,fullpart,firmsize,    &
                            paidhour,hourwage,inctot,incwage,i,j,iyr,iy,     &
                            locc1,locc2,locc3,inocclist
  integer, dimension(18) :: occlist1
  integer, dimension(18) :: occlist2
  integer, dimension(28) :: occlist3
  real, dimension(16)    :: popall,popsub1,popsub2,popsub3,popsub4,popsub5,  &
                            popsub6,popsub7,popsub8,popsub9,popsub10,        &
                            hrsall,hrssub1,hrssub2,hrssub3,hrssub4,hrssub5,  &
                            hrssub6,hrssub7,hrssub8,hrssub9,hrssub10
  
  open(unit=5, file='/home/cps/avghrs/avghrs.dat')
  open(unit=7, file='sweat.out')
  open(unit=8, file='cps.out')

  occlist1 = (/ 4,7,9,13,14,15,16,19,23,24,25,34,37,64,65,229,243,255 /)
  locc1    = 18 
  occlist2 = (/ 4,7,9,13,14,15,18,21,22,23,24,25,34,37,64,65,229,255 /)
  locc2    = 18 
  occlist3 = (/ 1,2,4,5,6,10,11,12,13,14,15,16,30,35,36,43,80,84,86,90,   &
                95,100,101,102,104,110,140,482 /)
  locc3    = 28

  popall   = 0.
  popsub1  = 0.
  popsub2  = 0.
  popsub3  = 0.
  popsub4  = 0.
  popsub5  = 0.
  popsub6  = 0.
  popsub7  = 0.
  popsub8  = 0.
  popsub9  = 0.
  popsub10 = 0.
  hrsall   = 0.
  hrssub1  = 0.
  hrssub2  = 0.
  hrssub3  = 0.
  hrssub4  = 0.
  hrssub5  = 0.
  hrssub6  = 0.
  hrssub7  = 0.
  hrssub8  = 0.
  hrssub9  = 0.
  hrssub10 = 0.

  do i=1,2451246
    read(5,'(I4,2I8,I2,3I1,2I2,I1,I3,I4,I2,I3,I4,3I2,3I1,I4,2I6)')       &
           year,perwt,blswt,age,sex,marst,popstat,educrec,               &
           empstat,labforce,occ,ind,classwkr,occly,indly,                &
           classswly,hrswork,uhrswork,fullpart,firmsize,                 &
           paidhour,hourwage,inctot,incwage

    iy        = year-1987
    inocclist = 0
    if (year<1992) then
      do j=1,locc1
        if (occ==occlist1(j)) inocclist = 1
      enddo
    endif
    if ((year>=1992).and.(year<=2002)) then
      do j=1,locc2
        if (occ==occlist2(j)) inocclist = 1
      enddo
    endif
    if (year==2003) then
      do j=1,locc3
        if (occ==occlist3(j)) inocclist = 1
      enddo
    endif  

    !
    ! Working age population is 16-64
    !
    if ((age>=16).and.(age<=64)) then
      popall(iy) = popall(iy)+float(perwt)
      hrsall(iy) = hrsall(iy)+float(hrswork*perwt)

      !
      ! Subgroup 1 are those not working last week 
      !
      if (empstat/=10) then

        popsub1(iy) = popsub1(iy)+float(perwt)
        hrssub1(iy) = hrssub1(iy)+float(hrswork*perwt)

      else
        !
        ! Of those working last week ...
        !
        if (educrec<8) then
          !
          ! Subgroup 2 is not highly educated 
          !
          popsub2(iy) = popsub2(iy)+float(perwt)
          hrssub2(iy) = hrssub2(iy)+float(hrswork*perwt)
        else
          !
          ! Subgroup 3 is highly educated but not in occlist occupations
          !
          if (inocclist==0) then 
            popsub3(iy) = popsub3(iy)+float(perwt)
            hrssub3(iy) = hrssub3(iy)+float(hrswork*perwt)
          else
            !
            ! Subgroup 4 is highly educated and in an occlist occupation
            !
            popsub4(iy) = popsub4(iy)+float(perwt)
            hrssub4(iy) = hrssub4(iy)+float(hrswork*perwt)
          endif
        endif

        !
        ! Subgroup 5 are proprietors in NIPA
        !
        if (classwkr==13) then
          popsub5(iy) = popsub5(iy)+float(perwt)
          hrssub5(iy) = hrssub5(iy)+float(hrswork*perwt)
        endif
        !
        ! Subgroup 6 are S-corporation shareholders
        !
        if (classwkr==14) then
          popsub6(iy) = popsub6(iy)+float(perwt)
          hrssub6(iy) = hrssub6(iy)+float(hrswork*perwt)
        endif
        if (classwkr==22) then
          !
          ! Subgroup 7 are employees in private households
          !
          if ((year<2003).and.((ind==761).or.(occ==404).or.(occ==407))) then
            popsub7(iy) = popsub7(iy)+float(perwt)
            hrssub7(iy) = hrssub7(iy)+float(hrswork*perwt)
          elseif ((year==2003).and.(ind==9290)) then
            popsub7(iy) = popsub7(iy)+float(perwt)
            hrssub7(iy) = hrssub7(iy)+float(hrswork*perwt)
          else
            !
            ! Subgroup 8 are private employees not in private households
            ! (this includes corporate, noncorporate, and nonprofit)
            !
            popsub8(iy) = popsub8(iy)+float(perwt)
            hrssub8(iy) = hrssub8(iy)+float(hrswork*perwt)
          endif
        endif
        !
        ! Subgroup 9 are government employees 
        !
        if ((classwkr>=25).and.((classwkr)<=28)) then
          popsub9(iy) = popsub9(iy)+float(perwt)
          hrssub9(iy) = hrssub9(iy)+float(hrswork*perwt)
        endif
        !
        ! Subgroup 10 are unpaid family workers
        !
        if (classwkr==29) then
          popsub10(iy) = popsub10(iy)+float(perwt)
          hrssub10(iy) = hrssub10(iy)+float(hrswork*perwt)
        endif
      endif
    endif
  enddo
  iyr = 1988
  write(7,*) '% Year   Ave Hours, by subgroup                  ',          &
             'Avg Numbers, by subgroup'
  write(7,*) '%         Total and Groups 1-4                   ',          &
             '      Groups 1-4   '
  write(8,*) '% Year   Ave Hours, by subgroup                  ',          &
             'Avg Numbers, by subgroup'
  write(8,*) '%         Total and Groups 1,5-9                 ',          &
             '      Groups 1,5-9 '
  do j=1,16
    write(7,'(1X,I4,9(1X,F7.4)')                                           &
                     iyr,hrsall(j)/popall(j),hrssub1(j)/popall(j),         &
                         hrssub2(j)/popall(j),hrssub3(j)/popall(j),        &  
                         hrssub4(j)/popall(j),popsub1(j)/popall(j),        & 
                         popsub2(j)/popall(j),popsub3(j)/popall(j),        & 
                         popsub4(j)/popall(j) 
    write(8,'(1X,I4,16(1X,F11.4)')                                          &
                     iyr,hrsall(j)/popall(j),hrssub1(j)/popall(j),         &
                         hrssub5(j)/popall(j),hrssub6(j)/popall(j),        &
                         hrssub7(j)/popall(j),hrssub8(j)/popall(j),        &
                         hrssub9(j)/popall(j),hrssub10(j)/popall(j),       &
                         popall(j)/1000000000.0,popsub1(j)/popall(j),      &
                         popsub5(j)/popall(j),popsub6(j)/popall(j),        &
                         popsub7(j)/popall(j),popsub8(j)/popall(j),        &
                         popsub9(j)/popall(j),popsub10(j)/popall(j)
    iyr = iyr+1
  enddo

end program read_cps
